<?php
if (!isset($gCms)) exit;

if (! $this->CheckPermission('Use MetaMax')) {
  return $this->DisplayErrorPage($id, $params, $returnid,$this->Lang('accessdenied'));
}

$this->SetPreference('keywordson_title',
		     (isset($params['keywordson_title'])?'1':'0'));
$this->SetPreference('key_number', $params['key_number']);
$this->SetPreference('key_length', $params['key_length']);
$this->SetPreference('key_density', $params['key_density']);
$this->SetPreference('key_default', $params['key_default']);
$this->SetPreference('keyskip_title', $params['keyskip_title']);

$params = array('tab_message'=> 'prefsupdated', 'active_tab' => 'keywords');
$this->Redirect($id, 'defaultadmin', '', $params);
?>